
scikit-learn API
================

This is the main class which makes it easy to insert
to use the prediction from an :epkg:`ONNX` files into a :epkg:`scikit-learn`
pipeline.

.. autosignature:: mlprodict.sklapi.onnx_transformer.OnnxTransformer
    :members:
